==> hadoop-client-api-3.3.1-sources.jar: org/apache/hadoop/io/retry/MultiException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.hadoop.shaded.org.apache.hadoop.org.apache.hadoop.shaded.io.retry;

import java.org.apache.hadoop.shaded.io.IOException;
import java.util.Map;

/**
 * Holder class that clients can use to return multiple exceptions.
 */
public class MultiException extends IOException {

  private final Map<String, Exception> exes;

  public MultiException(Map<String, Exception> exes) {
    this.exes = exes;
  }

  public Map<String, Exception> getExceptions() {
    return exes;
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder("{");
    for (Exception e : exes.values()) {
      sb.append(e.toString()).append(", ");
    }
    sb.append("}");
    return "MultiException[" + sb.toString() + "]";
  }
}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/io/retry/MultiException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.hadoop.shaded.org.apache.hadoop.io.retry;

import java.io.IOException;
import java.util.Map;

/**
 * Holder class that clients can use to return multiple exceptions.
 */
public class MultiException extends IOException {

  private final Map<String, Exception> exes;

  public MultiException(Map<String, Exception> exes) {
    this.exes = exes;
  }

  public Map<String, Exception> getExceptions() {
    return exes;
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder("{");
    for (Exception e : exes.values()) {
      sb.append(e.toString()).append(", ");
    }
    sb.append("}");
    return "MultiException[" + sb.toString() + "]";
  }
}
